# For plotting.

.CF.PT <- list(
  # color = c("#F9070E", "#0063FF", "#01B901", "#C000C5", "#FF7F00",
  #           "#A65628", "#F781BF", "#999999")

  ### in the order of NNA, NNT, NNG, NNC
  # color = c("#0063FF", "#01B901", "#C000C5", "#A65628", "#FF7F00", "#999999")

  ### in the order of NNA, NNC, NNG, NNT
  # color = c("#0063FF", "#A65628", "#C000C5", "#01B901", "#FF7F00", "#999999")

  color = c(
            rgb(  0,   0, 205, maxColorValue = 255), # bl
            rgb(255, 140,   0, maxColorValue = 255), # or
            rgb(148,   0, 211, maxColorValue = 255), # vi
            rgb( 50, 205,  50, maxColorValue = 255), # gr
            rgb(135, 206, 250, maxColorValue = 255), # sky blue
            # rgb(240, 230, 140, maxColorValue = 255)  # khaki
            rgb(255, 153, 255, maxColorValue = 255)  # khaki
           ),
  color.alpha = c(
                  rgb(  0,   0, 205, 65, maxColorValue = 255), # bl
                  rgb(255, 140,   0, 65, maxColorValue = 255), # or
                  rgb(148,   0, 211, 65, maxColorValue = 255), # vi
                  rgb( 50, 205,  50, 65, maxColorValue = 255), # gr
                  rgb(135, 206, 250, 65, maxColorValue = 255), # sky blue
                  # rgb(240, 230, 140, 192, maxColorValue = 255)  # khaki
                  rgb(255, 153, 255, 65, maxColorValue = 255)  # khaki
                 )
) # End of .CF.PT.

